namespace elm { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Slider::indicator_format_get() const
{
   const char * __return_value =  ::elm_obj_slider_indicator_format_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_format_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type indicator) const
{
    ::elm_obj_slider_indicator_format_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(indicator));
}
inline ::efl::eolian::return_traits<bool>::type Slider::indicator_show_get() const
{
   Eina_Bool __return_value =  ::elm_obj_slider_indicator_show_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_show_set( ::efl::eolian::in_traits<bool>::type show) const
{
    ::elm_obj_slider_indicator_show_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(show));
}
inline ::efl::eolian::return_traits<void>::type Slider::min_max_get( ::efl::eolian::out_traits<double>::type min,  ::efl::eolian::out_traits<double>::type max) const
{
   double __out_param_min = {};
   double __out_param_max = {};
    ::elm_obj_slider_min_max_get(this->_eo_ptr()
      , & __out_param_min
      , & __out_param_max);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(min, __out_param_min);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(max, __out_param_max);
}
inline ::efl::eolian::return_traits<void>::type Slider::min_max_set( ::efl::eolian::in_traits<double>::type min,  ::efl::eolian::in_traits<double>::type max) const
{
    ::elm_obj_slider_min_max_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(min)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(max));
}
inline ::efl::eolian::return_traits<bool>::type Slider::indicator_show_on_focus_get() const
{
   Eina_Bool __return_value =  ::elm_obj_slider_indicator_show_on_focus_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_show_on_focus_set( ::efl::eolian::in_traits<bool>::type flag) const
{
    ::elm_obj_slider_indicator_show_on_focus_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(flag));
}
inline ::efl::eolian::return_traits<double>::type Slider::step_get() const
{
   double __return_value =  ::elm_obj_slider_step_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::step_set( ::efl::eolian::in_traits<double>::type step) const
{
    ::elm_obj_slider_step_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(step));
}
inline ::efl::eolian::return_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type Slider::indicator_visible_mode_get() const
{
   Efl_Ui_Slider_Indicator_Visible_Mode __return_value =  ::elm_obj_slider_indicator_visible_mode_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_visible_mode_set( ::efl::eolian::in_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type indicator_visible_mode) const
{
    ::elm_obj_slider_indicator_visible_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Slider_Indicator_Visible_Mode,  ::efl::eolian::in_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type>(indicator_visible_mode));
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_format_function_set( ::efl::eolian::in_traits<slider_func_type>::type func,  ::efl::eolian::in_traits<slider_freefunc_type>::type free_func) const
{
    ::elm_obj_slider_indicator_format_function_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<slider_func_type,  ::efl::eolian::in_traits<slider_func_type>::type>(func)
      ,  ::efl::eolian::convert_to_c<slider_freefunc_type,  ::efl::eolian::in_traits<slider_freefunc_type>::type>(free_func));
}
inline ::efl::eolian::return_traits<bool>::type Slider::range_enabled_get() const
{
   Eina_Bool __return_value =  ::elm_obj_slider_range_enabled_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::range_enabled_set( ::efl::eolian::in_traits<bool>::type enable) const
{
    ::elm_obj_slider_range_enabled_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enable));
}
inline ::efl::eolian::return_traits<void>::type Slider::range_get( ::efl::eolian::out_traits<double>::type from,  ::efl::eolian::out_traits<double>::type to) const
{
   double __out_param_from = {};
   double __out_param_to = {};
    ::elm_obj_slider_range_get(this->_eo_ptr()
      , & __out_param_from
      , & __out_param_to);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(from, __out_param_from);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(to, __out_param_to);
}
inline ::efl::eolian::return_traits<void>::type Slider::range_set( ::efl::eolian::in_traits<double>::type from,  ::efl::eolian::in_traits<double>::type to) const
{
    ::elm_obj_slider_range_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(from)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(to));
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Slider::indicator_format_get() const
{
   const char * __return_value =  ::elm_obj_slider_indicator_format_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_format_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type indicator) const
{
    ::elm_obj_slider_indicator_format_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(indicator));
}
inline ::efl::eolian::return_traits<bool>::type Slider::indicator_show_get() const
{
   Eina_Bool __return_value =  ::elm_obj_slider_indicator_show_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_show_set( ::efl::eolian::in_traits<bool>::type show) const
{
    ::elm_obj_slider_indicator_show_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(show));
}
inline ::efl::eolian::return_traits<void>::type Slider::min_max_get( ::efl::eolian::out_traits<double>::type min,  ::efl::eolian::out_traits<double>::type max) const
{
   double __out_param_min = {};
   double __out_param_max = {};
    ::elm_obj_slider_min_max_get(this->_eo_ptr()
      , & __out_param_min
      , & __out_param_max);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(min, __out_param_min);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(max, __out_param_max);
}
inline ::efl::eolian::return_traits<void>::type Slider::min_max_set( ::efl::eolian::in_traits<double>::type min,  ::efl::eolian::in_traits<double>::type max) const
{
    ::elm_obj_slider_min_max_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(min)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(max));
}
inline ::efl::eolian::return_traits<bool>::type Slider::indicator_show_on_focus_get() const
{
   Eina_Bool __return_value =  ::elm_obj_slider_indicator_show_on_focus_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_show_on_focus_set( ::efl::eolian::in_traits<bool>::type flag) const
{
    ::elm_obj_slider_indicator_show_on_focus_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(flag));
}
inline ::efl::eolian::return_traits<double>::type Slider::step_get() const
{
   double __return_value =  ::elm_obj_slider_step_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::step_set( ::efl::eolian::in_traits<double>::type step) const
{
    ::elm_obj_slider_step_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(step));
}
inline ::efl::eolian::return_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type Slider::indicator_visible_mode_get() const
{
   Efl_Ui_Slider_Indicator_Visible_Mode __return_value =  ::elm_obj_slider_indicator_visible_mode_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_visible_mode_set( ::efl::eolian::in_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type indicator_visible_mode) const
{
    ::elm_obj_slider_indicator_visible_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Slider_Indicator_Visible_Mode,  ::efl::eolian::in_traits<Efl_Ui_Slider_Indicator_Visible_Mode>::type>(indicator_visible_mode));
}
inline ::efl::eolian::return_traits<void>::type Slider::indicator_format_function_set( ::efl::eolian::in_traits<slider_func_type>::type func,  ::efl::eolian::in_traits<slider_freefunc_type>::type free_func) const
{
    ::elm_obj_slider_indicator_format_function_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<slider_func_type,  ::efl::eolian::in_traits<slider_func_type>::type>(func)
      ,  ::efl::eolian::convert_to_c<slider_freefunc_type,  ::efl::eolian::in_traits<slider_freefunc_type>::type>(free_func));
}
inline ::efl::eolian::return_traits<bool>::type Slider::range_enabled_get() const
{
   Eina_Bool __return_value =  ::elm_obj_slider_range_enabled_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Slider::range_enabled_set( ::efl::eolian::in_traits<bool>::type enable) const
{
    ::elm_obj_slider_range_enabled_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enable));
}
inline ::efl::eolian::return_traits<void>::type Slider::range_get( ::efl::eolian::out_traits<double>::type from,  ::efl::eolian::out_traits<double>::type to) const
{
   double __out_param_from = {};
   double __out_param_to = {};
    ::elm_obj_slider_range_get(this->_eo_ptr()
      , & __out_param_from
      , & __out_param_to);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(from, __out_param_from);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(to, __out_param_to);
}
inline ::efl::eolian::return_traits<void>::type Slider::range_set( ::efl::eolian::in_traits<double>::type from,  ::efl::eolian::in_traits<double>::type to) const
{
    ::elm_obj_slider_range_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(from)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(to));
}
inline elm::Slider::operator ::elm::Slider() const { return *static_cast< ::elm::Slider const*>(static_cast<void const*>(this)); }
inline elm::Slider::operator ::elm::Slider&() { return *static_cast< ::elm::Slider*>(static_cast<void*>(this)); }
inline elm::Slider::operator ::elm::Slider const&() const { return *static_cast< ::elm::Slider const*>(static_cast<void const*>(this)); }
} }

